class meminfo:
    def __init__(self):
        self.java_heap = 0
        self.native_heap = 0
        self.code = 0
        self.stack = 0
        self.graphics = 0
        self.other = 0
        self.system = 0
        self.total = 0


