# -*- coding: utf-8 -*-

VERSION = [0, 0, 4]

DEBUG = False

# dump时间间隔(s)
DUMP_INTERVAL = 1

# 表单名称
SHEET_NAME = "memory"


COLORS = ['red', 'yellow', 'gray', 'blue', 'black', 'pink', '#ff34b3', '#fff8dc']
